delu.hardware
=============

.. currentmodule:: delu.hardware

.. automodule:: delu.hardware

----

.. warning::
   The API listed below is deprecated.

.. autosummary::
    :nosignatures:
    :toctree: api

    free_memory
    get_gpus_info
